@@ -1,7 +1,7 @@
-from pypyARXaaS import ARXaaS
-from pypyARXaaS.privacy_models import KAnonymity, LDiversityDistinct
-from pypyARXaaS import AttributeType, Dataset
-from pypyARXaaS.hierarchy import IntervalHierarchyBuilder, DateHierarchyBuilder, RedactionHierarchyBuilder
+from pyarxaas import ARXaaS
+from pyarxaas.privacy_models import KAnonymity, LDiversityDistinct
+from pyarxaas import AttributeType, Dataset
+from pyarxaas.hierarchy import IntervalHierarchyBuilder, DateHierarchyBuilder, RedactionHierarchyBuilder
 
 import pandas as pd
 
